@@ -1,4 +1,4 @@
-/* $Id: cdb.c,v 1.7 2003/08/14 21:03:34 mjt Exp $
+/* $Id: cdb.c,v 1.11 2005/04/18 00:26:40 mjt Exp $
  * cdb command line tool
  *
  * This file is a part of tinycdb package by Michael Tokarev, mjt@corpit.ru.
@@ -143,7 +143,7 @@ dmode(char *dbname, char mode, int flags)
       if (printf(mode == 'd' ? "+%u,%u:" : "+%u:", klen, vlen) < 0) return -1;
     if (fcpy(f, stdout, klen, &pos, eod) != 0) return -1;
     if (mode == 'd')
-      if (!fputs(flags & F_MAP ? " " : "->", stdout))
+      if (fputs(flags & F_MAP ? " " : "->", stdout) < 0)
         return -1;
     if (fcpy(f, mode == 'd' ? stdout : NULL, vlen, &pos, eod) != 0)
       return -1;
@@ -398,7 +398,7 @@ int main(int argc, char **argv)
   if (argc == 1)
     error(0, "no arguments given");
 
-  while((c = getopt(argc, argv, "qdlcsht:n:mwrue")) != EOF)
+  while((c = getopt(argc, argv, "qdlcsht:n:mwrue0")) != EOF)
     switch(c) {
     case 'q': case 'd':  case 'l': case 'c': case 's':
       if (mode && mode != c)
@@ -410,18 +410,22 @@ int main(int argc, char **argv)
     case 'e': flags |= F_WARNDUP | F_ERRDUP; break;
     case 'r': flags = (flags & ~F_DUPMASK) | CDB_PUT_REPLACE; break;
     case 'u': flags = (flags & ~F_DUPMASK) | CDB_PUT_INSERT; break;
+    case '0': flags = (flags & ~F_DUPMASK) | CDB_PUT_REPLACE0; break;
     case 'm': flags |= F_MAP; break;
     case 'n':
       if ((num = atoi(optarg)) <= 0)
         error(0, "invalid record number `%s'", optarg);
       break;
     case 'h':
+#define strify(x) _strify(x)
+#define _strify(x) #x
       printf("\
-%s: Constant DataBase (CDB) tool. Usage is:\n\
+%s: Constant DataBase (CDB) tool version " strify(TINYCDB_VERSION)
+". Usage is:\n\
  query:  %s -q [-m] [-n recno|-a] cdbfile key\n\
  dump:   %s -d [-m] [cdbfile|-]\n\
  list:   %s -l [-m] [cdbfile|-]\n\
- create: %s -c [-m] [-wrue] [-t tempfile] cdbfile [infile...]\n\
+ create: %s -c [-m] [-wrue0] [-t tempfile] cdbfile [infile...]\n\
  stats:  %s -s [cdbfile|-]\n\
  help:   %s -h\n\
 ", progname, progname, progname, progname, progname, progname, progname);
