@@ -1,4 +1,4 @@
-/* $Id: cdb_make.c,v 1.7 2003/11/03 16:42:41 mjt Exp $
+/* $Id: cdb_make.c,v 1.10 2005/04/18 00:18:19 mjt Exp $
  * basic cdb creation routines
  *
  * This file is a part of tinycdb package by Michael Tokarev, mjt@corpit.ru.
@@ -29,8 +29,8 @@ cdb_make_start(struct cdb_make *cdbmp, int fd)
   return 0;
 }
 
-static int
-ewrite(int fd, const char *buf, int len)
+int
+_cdb_make_fullwrite(int fd, const char *buf, unsigned len)
 {
   while(len) {
     int l = write(fd, buf, len);
@@ -42,6 +42,17 @@ ewrite(int fd, const char *buf, int len)
   return 0;
 }
 
+int
+_cdb_make_flush(struct cdb_make *cdbmp) {
+  unsigned len = cdbmp->cdb_bpos - cdbmp->cdb_buf;
+  if (len) {
+    if (_cdb_make_fullwrite(cdbmp->cdb_fd, cdbmp->cdb_buf, len) < 0)
+      return -1;
+    cdbmp->cdb_bpos = cdbmp->cdb_buf;
+  }
+  return 0;
+}
+
 int
 _cdb_make_write(struct cdb_make *cdbmp, const char *ptr, unsigned len)
 {
@@ -49,17 +60,17 @@ _cdb_make_write(struct cdb_make *cdbmp, const char *ptr, unsigned len)
   cdbmp->cdb_dpos += len;
   if (len > l) {
     memcpy(cdbmp->cdb_bpos, ptr, l);
-    if (ewrite(cdbmp->cdb_fd, cdbmp->cdb_buf, sizeof(cdbmp->cdb_buf)) < 0)
+    cdbmp->cdb_bpos += l;
+    if (_cdb_make_flush(cdbmp) < 0)
       return -1;
     ptr += l; len -= l;
     l = len / sizeof(cdbmp->cdb_buf);
     if (l) {
       l *= sizeof(cdbmp->cdb_buf);
-      if (ewrite(cdbmp->cdb_fd, ptr, l) < 0)
-	return -1;
+      if (_cdb_make_fullwrite(cdbmp->cdb_fd, ptr, l) < 0)
+        return -1;
       ptr += l; len -= l;
     }
-    cdbmp->cdb_bpos = cdbmp->cdb_buf;
   }
   if (len) {
     memcpy(cdbmp->cdb_bpos, ptr, len);
@@ -117,11 +128,11 @@ cdb_make_finish_internal(struct cdb_make *cdbmp)
       htab[i].hval = htab[i].rpos = 0;
     for (rl = cdbmp->cdb_rec[t]; rl; rl = rl->next)
       for (i = 0; i < rl->cnt; ++i) {
-	hi = (rl->rec[i].hval >> 8) % len;
-	while(htab[hi].rpos)
-	  if (++hi == len)
-	    hi = 0;
-	htab[hi] = rl->rec[i];
+       hi = (rl->rec[i].hval >> 8) % len;
+        while(htab[hi].rpos)
+          if (++hi == len)
+            hi = 0;
+        htab[hi] = rl->rec[i];
       }
     for (i = 0; i < len; ++i) {
       cdb_pack(htab[i].hval, p + (i << 3));
@@ -133,17 +144,15 @@ cdb_make_finish_internal(struct cdb_make *cdbmp)
     }
   }
   free(p);
-  if (cdbmp->cdb_bpos != cdbmp->cdb_buf &&
-      ewrite(cdbmp->cdb_fd, cdbmp->cdb_buf,
-	     cdbmp->cdb_bpos - cdbmp->cdb_buf) != 0)
-      return -1;
+  if (_cdb_make_flush(cdbmp) < 0)
+    return -1;
   p = cdbmp->cdb_buf;
   for (t = 0; t < 256; ++t) {
     cdb_pack(hpos[t], p + (t << 3));
     cdb_pack(hcnt[t], p + (t << 3) + 4);
   }
   if (lseek(cdbmp->cdb_fd, 0, 0) != 0 ||
-      ewrite(cdbmp->cdb_fd, p, 2048) != 0)
+      _cdb_make_fullwrite(cdbmp->cdb_fd, p, 2048) != 0)
     return -1;
 
   return 0;
