@@ -1,4 +1,4 @@
-/* $Id: cdb_make_add.c,v 1.6 2003/11/03 16:42:41 mjt Exp $
+/* $Id: cdb_make_add.c,v 1.7 2005/04/18 00:19:12 mjt Exp $
  * basic cdb_make_add routine
  *
  * This file is a part of tinycdb package by Michael Tokarev, mjt@corpit.ru.
@@ -9,29 +9,29 @@
 #include "cdb_int.h"
 
 int
-cdb_make_add(struct cdb_make *cdbmp,
-	     const void *key, unsigned klen,
-	     const void *val, unsigned vlen)
+_cdb_make_add(struct cdb_make *cdbmp, unsigned hval,
+              const void *key, unsigned klen,
+              const void *val, unsigned vlen)
 {
   unsigned char rlen[8];
-  unsigned hval;
   struct cdb_rl *rl;
+  unsigned i;
   if (klen > 0xffffffff - (cdbmp->cdb_dpos + 8) ||
       vlen > 0xffffffff - (cdbmp->cdb_dpos + klen + 8))
     return errno = ENOMEM, -1;
-  hval = cdb_hash(key, klen);
-  rl = cdbmp->cdb_rec[hval&255];
+  i = hval & 255;
+  rl = cdbmp->cdb_rec[i];
   if (!rl || rl->cnt >= sizeof(rl->rec)/sizeof(rl->rec[0])) {
     rl = (struct cdb_rl*)malloc(sizeof(struct cdb_rl));
     if (!rl)
       return errno = ENOMEM, -1;
     rl->cnt = 0;
-    rl->next = cdbmp->cdb_rec[hval&255];
-    cdbmp->cdb_rec[hval&255] = rl;
+    rl->next = cdbmp->cdb_rec[i];
+    cdbmp->cdb_rec[i] = rl;
   }
-  rl->rec[rl->cnt].hval = hval;
-  rl->rec[rl->cnt].rpos = cdbmp->cdb_dpos;
-  ++rl->cnt;
+  i = rl->cnt++;
+  rl->rec[i].hval = hval;
+  rl->rec[i].rpos = cdbmp->cdb_dpos;
   ++cdbmp->cdb_rcnt;
   cdb_pack(klen, rlen);
   cdb_pack(vlen, rlen + 4);
@@ -42,3 +42,9 @@ cdb_make_add(struct cdb_make *cdbmp,
   return 0;
 }
 
+int
+cdb_make_add(struct cdb_make *cdbmp,
+             const void *key, unsigned klen,
+             const void *val, unsigned vlen) {
+  return _cdb_make_add(cdbmp, cdb_hash(key, klen), key, klen, val, vlen);
+}
